@@ -4,7 +4,7 @@ import warnings
 import cv2
 from tensorflow import keras
 
-from utils.anchors import anchors_for_shape, anchor_targets_bbox, AnchorParameters
+from utils.anchors import anchors_for_shape, anchor_targets_bbox
 
 
 class Generator(keras.utils.Sequence):
@@ -21,8 +21,6 @@ class Generator(keras.utils.Sequence):
             batch_size=1,
             group_method='ratio',  # one of 'none', 'random', 'ratio'
             shuffle_groups=True,
-            detect_text=False,
-            detect_quadrangle=False,
     ):
         """
         Initialize Generator object.
@@ -38,15 +36,10 @@ class Generator(keras.utils.Sequence):
         self.batch_size = int(batch_size)
         self.group_method = group_method
         self.shuffle_groups = shuffle_groups
-        self.detect_text = detect_text
-        self.detect_quadrangle = detect_quadrangle
         self.image_size = image_sizes[phi]
         self.groups = None
-        self.anchor_parameters = AnchorParameters.default if not self.detect_text else AnchorParameters(
-            ratios=(0.25, 0.5, 1., 2.),
-            sizes=(16, 32, 64, 128, 256))
-        self.anchors = anchors_for_shape((self.image_size, self.image_size), anchor_params=self.anchor_parameters)
-        self.num_anchors = self.anchor_parameters.num_anchors()
+        self.anchors = anchors_for_shape((self.image_size, self.image_size))
+        self.current_index = 0
 
         # Define groups
         self.group_images()
@@ -58,6 +51,7 @@ class Generator(keras.utils.Sequence):
     def on_epoch_end(self):
         if self.shuffle_groups:
             random.shuffle(self.groups)
+        self.current_index = 0
 
     def size(self):
         """
@@ -193,8 +187,8 @@ class Generator(keras.utils.Sequence):
             annotations['bboxes'][:, 3] = np.clip(annotations['bboxes'][:, 3], 1, image_height - 1)
             # test x2 < x1 | y2 < y1 | x1 < 0 | y1 < 0 | x2 <= 0 | y2 <= 0 | x2 >= image.shape[1] | y2 >= image.shape[0]
             small_indices = np.where(
-                (annotations['bboxes'][:, 2] - annotations['bboxes'][:, 0] < 3) |
-                (annotations['bboxes'][:, 3] - annotations['bboxes'][:, 1] < 3)
+                (annotations['bboxes'][:, 2] - annotations['bboxes'][:, 0] < 10) |
+                (annotations['bboxes'][:, 3] - annotations['bboxes'][:, 1] < 10)
             )[0]
 
             # delete invalid indices
@@ -255,7 +249,9 @@ class Generator(keras.utils.Sequence):
         Randomly transforms image and annotation.
         """
         # randomly transform both image and annotations
-        image, annotations = self.misc_effect(image, annotations)
+        image, boxes = self.misc_effect(image, annotations['bboxes'])
+        # Transform the bounding boxes in the annotations.
+        annotations['bboxes'] = boxes
         return image, annotations
 
     def random_misc_group(self, image_group, annotations_group):
@@ -287,10 +283,7 @@ class Generator(keras.utils.Sequence):
         annotations['bboxes'] *= scale
         annotations['bboxes'][:, [0, 2]] += offset_w
         annotations['bboxes'][:, [1, 3]] += offset_h
-        if self.detect_quadrangle:
-            annotations['quadrangles'] *= scale
-            annotations['quadrangles'][:, :, 0] += offset_w
-            annotations['quadrangles'][:, :, 1] += offset_h
+        # print(annotations['bboxes'][:, [2, 3]] - annotations['bboxes'][:, [0, 1]])
         return image, annotations
 
     def preprocess_group(self, image_group, annotations_group):
@@ -329,27 +322,6 @@ class Generator(keras.utils.Sequence):
         batch_images = np.array(image_group).astype(np.float32)
         return [batch_images]
 
-    def compute_alphas_and_ratios(self, annotations_group):
-        for i, annotations in enumerate(annotations_group):
-            quadrangles = annotations['quadrangles']
-            alphas = np.zeros((quadrangles.shape[0], 4), dtype=np.float32)
-            xmin = np.min(quadrangles, axis=1)[:, 0]
-            ymin = np.min(quadrangles, axis=1)[:, 1]
-            xmax = np.max(quadrangles, axis=1)[:, 0]
-            ymax = np.max(quadrangles, axis=1)[:, 1]
-            # alpha1, alpha2, alpha3, alpha4
-            alphas[:, 0] = (quadrangles[:, 0, 0] - xmin) / (xmax - xmin)
-            alphas[:, 1] = (quadrangles[:, 1, 1] - ymin) / (ymax - ymin)
-            alphas[:, 2] = (xmax - quadrangles[:, 2, 0]) / (xmax - xmin)
-            alphas[:, 3] = (ymax - quadrangles[:, 3, 1]) / (ymax - ymin)
-            annotations['alphas'] = alphas
-            # ratio
-            area1 = 0.5 * alphas[:, 0] * (1 - alphas[:, 3])
-            area2 = 0.5 * alphas[:, 1] * (1 - alphas[:, 0])
-            area3 = 0.5 * alphas[:, 2] * (1 - alphas[:, 1])
-            area4 = 0.5 * alphas[:, 3] * (1 - alphas[:, 2])
-            annotations['ratios'] = 1 - area1 - area2 - area3 - area4
-
     def compute_targets(self, image_group, annotations_group):
         """
         Compute target outputs for the network using images and their annotations.
@@ -362,12 +334,11 @@ class Generator(keras.utils.Sequence):
             self.anchors,
             image_group,
             annotations_group,
-            num_classes=self.num_classes(),
-            detect_quadrangle=self.detect_quadrangle
+            self.num_classes()
         )
         return list(batches_targets)
 
-    def compute_inputs_targets(self, group, debug=False):
+    def compute_inputs_targets(self, group):
         """
         Compute inputs and target outputs for the network.
         """
@@ -395,12 +366,8 @@ class Generator(keras.utils.Sequence):
         # check validity of annotations
         image_group, annotations_group = self.clip_transformed_annotations(image_group, annotations_group, group)
 
-        assert len(image_group) != 0
-        assert len(image_group) == len(annotations_group)
-
-        if self.detect_quadrangle:
-            # compute alphas and ratio for targets
-            self.compute_alphas_and_ratios(annotations_group)
+        if len(image_group) == 0:
+            return None, None
 
         # compute network inputs
         inputs = self.compute_inputs(image_group, annotations_group)
@@ -408,9 +375,6 @@ class Generator(keras.utils.Sequence):
         # compute network targets
         targets = self.compute_targets(image_group, annotations_group)
 
-        if debug:
-            return inputs, targets, annotations_group
-
         return inputs, targets
 
     def __len__(self):
@@ -424,8 +388,19 @@ class Generator(keras.utils.Sequence):
         """
         Keras sequence method for generating batches.
         """
-        group = self.groups[index]
+        group = self.groups[self.current_index]
         inputs, targets = self.compute_inputs_targets(group)
+        while inputs is None:
+            current_index = self.current_index + 1
+            if current_index >= len(self.groups):
+                current_index = current_index % (len(self.groups))
+            self.current_index = current_index
+            group = self.groups[self.current_index]
+            inputs, targets = self.compute_inputs_targets(group)
+        current_index = self.current_index + 1
+        if current_index >= len(self.groups):
+            current_index = current_index % (len(self.groups))
+        self.current_index = current_index
         return inputs, targets
 
     def preprocess_image(self, image):
@@ -468,13 +443,13 @@ class Generator(keras.utils.Sequence):
         image_group, annotations_group = self.filter_annotations(image_group, annotations_group, group)
 
         # randomly apply visual effect
-        # image_group, annotations_group = self.random_visual_effect_group(image_group, annotations_group)
+        image_group, annotations_group = self.random_visual_effect_group(image_group, annotations_group)
 
         # randomly transform data
         # image_group, annotations_group = self.random_transform_group(image_group, annotations_group)
 
         # randomly apply misc effect
-        # image_group, annotations_group = self.random_misc_group(image_group, annotations_group)
+        image_group, annotations_group = self.random_misc_group(image_group, annotations_group)
 
         # perform preprocessing steps
         image_group, annotations_group = self.preprocess_group(image_group, annotations_group)
@@ -482,10 +457,4 @@ class Generator(keras.utils.Sequence):
         # check validity of annotations
         image_group, annotations_group = self.clip_transformed_annotations(image_group, annotations_group, group)
 
-        assert len(image_group) != 0
-        assert len(image_group) == len(annotations_group)
-
-        # compute alphas for targets
-        self.compute_alphas_and_ratios(annotations_group)
-
         return image_group, annotations_group
